;
;   Module name      :	Au3Check.au3
;   Version          :	1.11
;   Started on       :	December 5, 2010
;   Completed on     :	December 13, 2010
;   Author           :  J.Hubb
;
;   Module type      :	Main
;   Description      :	None
;
;   Developed under  :	AutoIt 3.2.10.0
;   Sw requirements  :	CmdLine.au3
;
;   Parameters       :	None
;   Notes - usage    :	None
;


;--- Global directives -----------------------------------------------------------------------------



#NoTrayIcon
; Opt("TrayIconDebug", 1)		; Remove comment to enable during debug

Opt("MustDeclareVars", 1)
Opt("GUICloseOnESC", 0)



;--- Include files ---------------------------------------------------------------------------------



#include <Constants.au3>
#include <CmdLine.au3>
#include <File.au3>



;--- Global constants ------------------------------------------------------------------------------



const $FILE_NAME = "Au3Check.au3"
const $MODULE_VER = "1.11"
const $MODULE_NAME = $FILE_NAME & " " & $MODULE_VER & "; Open Source on December 13, 2010 by J.Hubb."

; Error codes
const $NO_ERROR = 0
const $PARAM_ERR = 255

; Help messages, switches and parameters
const $HELP_MSG = _
	"Usage: " & $FILE_NAME & " [/?] [/ver] [FilePath.au3]" & @CR & _
	@CR & _
	"Checks the syntax of AutoIt3 script [FilePath.au3]; if omitted an OpenDialog is used."

; Switch definitions (the first must be: $SWITCH_ERR = $CL_SWITCH_ERR)
enum $SWITCH_ERR = $CL_SWITCH_ERR, $SWITCH_HELP, $SWITCH_VER
const $SWITCH_COUNT = 3										; Total number of switch definitions
const $SWITCH[$SWITCH_COUNT][4] = _
	[ _
		[$SWITCH_ERR,		"",			0,	""], _
		[$SWITCH_HELP,		"/?",		0,	"display this help and exit"], _
		[$SWITCH_VER,		"/ver",		0,	"print version information and exit"] _
	]
	
const $INI_MAIN_SECT = "General"
const $CHK_PROG_PATH_VAR = "ChkProgPath"
const $CHK_PROG_NAME_DEF = "Au3Check"
const $CHK_PROG_PARAM_VAR = "ChkProgParam"
const $CHK_PROG_PARAM_DEF = "-d -w 1 -w 2 -w 3 -w 4 -w 5 -w 6"



;--- Global variables ------------------------------------------------------------------------------



global $Curr_switch, $Curr_switch_ndx, $Curr_params_ndx
global $Au3_file_path



;--- Functions code --------------------------------------------------------------------------------



func RunChecks($f)
;---
; Runs the AutoIt3 syntax checker program and displays the results in a Message Box with the
; correct icon on errors, only warning or no problem.
;
; $f	file path to be checked
; ret	nothing
;---
	local $tmp_drive, $tmp_dir, $tmp_name, $tmp_ext
	local $ini_path
	local $chk_prog_path, $chk_prog_param
	local $tmp_file_name = _TempFile(@TempDir, "~", ".ac", 2)		; Needed to keep command line short enough
	local $exit_code, $line

	_PathSplit(@ScriptFullPath, $tmp_drive, $tmp_dir, $tmp_name, $tmp_ext)
	$ini_path = _PathMake($tmp_drive, $tmp_dir, $tmp_name, "ini")
	_PathSplit(@AutoItExe, $tmp_drive, $tmp_dir, $tmp_name, $tmp_ext)
	$chk_prog_path = IniRead($ini_path, $INI_MAIN_SECT, $CHK_PROG_PATH_VAR, _PathMake($tmp_drive, $tmp_dir, $CHK_PROG_NAME_DEF, $tmp_ext))
	if (not FileExists($chk_prog_path)) then
		ShowError("The program '" & $chk_prog_path & "' does not exist.")
	endif
	_PathSplit($chk_prog_path, $tmp_drive, $tmp_dir, $tmp_name, $tmp_ext)	; Needed to keep command line short enough
	$chk_prog_param = IniRead($ini_path, $INI_MAIN_SECT, $CHK_PROG_PARAM_VAR, $CHK_PROG_PARAM_DEF)
	$exit_code = RunWait(@ComSpec & " /c " & $tmp_name & " " & $chk_prog_param & " """ & $f & """ > " & $tmp_file_name, $tmp_drive & $tmp_dir, @SW_HIDE)
	$line = FileRead($tmp_file_name)
	FileDelete($tmp_file_name)
	switch $exit_code
		case 0
			MsgBox($MB_OK + $MB_ICONASTERISK, $FILE_NAME, $line)
		case 1
			ShowWarning($line)
		case else
			ShowError($line)
	endswitch
endfunc



func ShowError($msg, $code = $NO_ERROR)
;---
; Displays in a Message Box an error message and stops the execution of the script with the
; specified exit code or $NO_ERROR if not specified.
;
; $msg	error message
; $code	exit code
; ret	nothing
;---
	MsgBox($MB_OK + $MB_ICONHAND, $FILE_NAME, $msg)
	Exit($code)
endfunc



func ShowHelp()
;---
; Displays in a Message Box the help message and stops the execution of the script.
;
; ret	nothing
;---
	local $s = $HELP_MSG
	local $n
	
	for $n = 1 to ($SWITCH_COUNT - 1)
		$s &= @CR & $SWITCH[$n][1] & Chr(9) & $SWITCH[$n][3]
	next
	MsgBox($MB_OK + $MB_ICONASTERISK, $FILE_NAME, $s)
	Exit
endfunc



func ShowVersion()
;---
; Displays in a Message Box the version message and stops the execution of the script.
;
; ret	nothing
;---
	MsgBox($MB_OK + $MB_ICONASTERISK, $FILE_NAME, $MODULE_NAME)
	Exit
endfunc



func ShowWarning($msg)
;---
; Displays in a Message Box a warning message without stopping the execution of the script.
;
; $msg	warning message
; ret	nothing
;---
	MsgBox($MB_OK + $MB_ICONEXCLAMATION, $FILE_NAME, $msg)
endfunc



;--- Main code -------------------------------------------------------------------------------------



while (CLGetOpts($SWITCH, $Curr_switch, $Curr_switch_ndx, $Curr_params_ndx))
	switch $Curr_switch
		case $SWITCH_ERR
			$Au3_file_path = $CmdLine[$Curr_switch_ndx]
			ExitLoop
		case $SWITCH_HELP
			ShowHelp()
		case $SWITCH_VER
			ShowVersion()
	endswitch
wend

if ($Au3_file_path == "") then
	$Au3_file_path = FileOpenDialog($FILE_NAME, "", "AutoIt3 files (*.au3)|All (*.*)", 1 + 2)
endif
if ($Au3_file_path <> "") then
	RunChecks($Au3_file_path)
endif
